@@ -1,5 +1,5 @@
 /*
- * Copyright © 2009-2015 Siyan Panayotov <contact@siyanpanayotov.com>
+ * Copyright © 2009-2018 Siyan Panayotov <contact@siyanpanayotov.com>
  *
  * This file is part of Viewnior.
  *
@@ -33,7 +33,7 @@ static void vnr_properties_dialog_update_metadata(VnrPropertiesDialog *dialog);
 static gboolean
 key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
-    if(event->keyval == GDK_Escape)
+    if(event->keyval == GDK_KEY_Escape)
     {
         gtk_widget_hide(widget);
         return TRUE;
